Summary:	Recursor for PowerDNS
Name:		pdns-recursor
Version:	4.1.16
Release:	%mkrel 1
License:	GPLv2
Group:		System/Servers
URL:		http://www.powerdns.com/
Source0:	http://downloads.powerdns.com/releases/pdns-recursor-%{version}.tar.bz2
Requires(post): systemd >= %{systemd_required_version}
Requires(post): rpm-helper
Requires(preun): rpm-helper
Requires(pre): rpm-helper
Requires(postun): rpm-helper
BuildRequires:	libstdc++-devel
BuildRequires:	pkgconfig(zlib)
BuildRequires:	boost-devel
BuildRequires:	pkgconfig(lua)
BuildRequires:	pkgconfig(systemd)
BuildRequires:	pkgconfig(libsodium)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(protobuf)


%description
With a small codebase, the PowerDNS Recursor is an advanced recursor currently
serving the DNS resolving needs of over 2 million Internet connections. Besides
high performance (using kqueue or epoll, over 15 thousand qps on commodity
hardware), it provides advanced anti-spoofing measures. In addition, the
program caches server performance and timeouts, making it both network and user
friendly. It also has built-in hooks for making graphs with rrdtool, providing
insight into nameserver performance.

%prep

%setup -q
%autopatch -p3
chmod 644 rrd/*

%build
%serverbuild

%configure \
 --sysconfdir=%{_sysconfdir}/powerdns \
 --enable-unit-tests \
 --enable-libsodium \
 --enable-systemd

%{__aclocal}
%{__automake} --add-missing
%make_build

%check

# Temporarily disable tests under x86 due to BS memory exhaustion issue
%ifnarch %ix86
if ! %make_build check; then cat test-suite.log; exit 1; fi
%endif

%install

%make_install

rm -f %{buildroot}%{_sysconfdir}/powerdns/*
%{buildroot}%{_sbindir}/pdns_recursor --config > %{buildroot}%{_sysconfdir}/powerdns/recursor.conf

# fix the config
cat >> %{buildroot}%{_sysconfdir}/powerdns/recursor.conf << EOF
socket-dir=/run/powerdns/
soa-minimum-ttl=0
local-port=5300
local-address=127.0.0.1
trace=off
daemon=yes
quiet=on
setgid=powerdns
setuid=powerdns
EOF

install -d %{buildroot}%{_tmpfilesdir}
cat <<EOF > %{buildroot}%{_tmpfilesdir}/%{name}.conf
d /run/powerdns 0755 root powerdns
EOF

%pre
%_pre_useradd powerdns /var/lib/powerdns /bin/false

%post
%_tmpfilescreate %{name}
%_post_service %{name}

%preun
%_preun_service %{name}

%postun
%_postun_userdel %{name}

%files
%doc COPYING README rrd
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/powerdns/recursor.conf
%{_tmpfilesdir}/%{name}.conf
%{_unitdir}/%{name}.service
%{_unitdir}/%{name}@.service
%{_bindir}/rec_control
%{_sbindir}/pdns_recursor
%{_mandir}/man1/pdns_recursor.1*
%{_mandir}/man1/rec_control.1*


%changelog
* Tue May 19 2020 neoclust <neoclust> 4.1.16-1.mga7
+ Revision: 1586276
- New version 4.1.16: Fixes for CVE-2020-10995, CVE-2020-12244 and CVE-2020-10030

* Sun May 12 2019 luigiwalser <luigiwalser> 4.1.12-1.mga7
+ Revision: 1397342
- 4.1.12

* Sat Feb 02 2019 luigiwalser <luigiwalser> 4.1.11-1.mga7
+ Revision: 1362673
- 4.1.11

* Mon Jan 21 2019 luigiwalser <luigiwalser> 4.1.9-1.mga7
+ Revision: 1358720
- 4.1.9 (fixes CVE-2019-3806 and CVE-2019-3807)

* Tue Jan 01 2019 luigiwalser <luigiwalser> 4.1.8-1.mga7
+ Revision: 1347842
- 4.1.8 (fixes CVE-2018-10851, CVE-2018-14626, CVE-2018-14644, CVE-2018-16855)

* Tue Oct 16 2018 wally <wally> 4.1.4-2.mga7
+ Revision: 1321077
- rebuild for new boost 1.68.0

* Sun Sep 23 2018 daviddavid <daviddavid> 4.1.4-1.mga7
+ Revision: 1297061
- new version: 4.1.4

* Sun May 20 2018 mitya <mitya> 4.1.2-3.mga7
+ Revision: 1230753
+ rebuild (emptylog)

* Wed Apr 25 2018 mitya <mitya> 4.1.2-1.mga7
+ Revision: 1222207
- New version 4.1.2
- Drop patch #0 (merged upstream)
- Temporarily disable tests under x86

* Sun Apr 22 2018 mitya <mitya> 4.1.1-1.mga7
+ Revision: 1220856
- New version 4.1.1
+ daviddavid <daviddavid>
- rebuild for new protobuf 3.5

* Mon Dec 25 2017 wally <wally> 4.1.0-3.mga7
+ Revision: 1184762
- rebuild for new boost

* Tue Dec 05 2017 mitya <mitya> 4.1.0-2.mga7
+ Revision: 1181419
- New version 4.1.0

* Tue Nov 28 2017 mitya <mitya> 4.0.7-1.mga7
+ Revision: 1180180
- New version 4.0.7

* Tue Nov 21 2017 tv <tv> 4.0.6-2.mga7
+ Revision: 1178338
- rebuild for boost 1.65

* Wed Nov 15 2017 mitya <mitya> 4.0.6-1.mga7
+ Revision: 1177401
- New version 4.0.6
- Enable protobuf and libsodium
- Enable unit tests
- Use stock systemd unit file
- Tweak runtime dir perms, see https://github.com/PowerDNS/pdns/issues/4826
- Revive pdns-recursor
+ akien <akien>
- Package was removed from cauldron, obsolete

* Tue Feb 16 2016 umeabot <umeabot> 3.6.4-3.mga6
+ Revision: 962003
- Mageia 6 Mass Rebuild

* Tue Oct 27 2015 daviddavid <daviddavid> 3.6.4-2.mga6
+ Revision: 895881
- do not strip binaries to fix empty debuginfo

* Tue Jul 07 2015 luigiwalser <luigiwalser> 3.6.4-1.mga6
+ Revision: 852341
- 3.6.4

* Thu Apr 23 2015 luigiwalser <luigiwalser> 3.6.3-1.mga5
+ Revision: 820595
- 3.6.3 (fixes CVE-2015-1868)

* Tue Dec 09 2014 luigiwalser <luigiwalser> 3.6.2-2.mga5
+ Revision: 802425
- remove invalid directive from config file

* Fri Nov 21 2014 luigiwalser <luigiwalser> 3.6.2-1.mga5
+ Revision: 798196
- 3.6.2

* Wed Oct 15 2014 umeabot <umeabot> 3.6.1-3.mga5
+ Revision: 744109
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.6.1-2.mga5
+ Revision: 683392
- Mageia 5 Mass Rebuild

* Wed Sep 10 2014 oden <oden> 3.6.1-1.mga5
+ Revision: 674516
- 3.6.1

* Sun Jun 29 2014 tv <tv> 3.6.0-1.mga5
+ Revision: 641216
- drop merged patch
- new release
- rebuild with lua-5.2

* Thu Jun 12 2014 oden <oden> 3.5.3-3.mga5
+ Revision: 635770
- P0: fix a DoS (http://blog.powerdns.com/2014/02/06/related-to-recent-dos-attacks-recursor-configuration-file-guidance/)

* Sat Oct 19 2013 umeabot <umeabot> 3.5.3-2.mga4
+ Revision: 535161
- Mageia 4 Mass Rebuild

* Thu Sep 19 2013 oden <oden> 3.5.3-1.mga4
+ Revision: 481382
- 3.5.3

* Wed Jul 10 2013 oden <oden> 3.5.2-1.mga4
+ Revision: 452454
- 3.5.2

* Sun May 05 2013 tmb <tmb> 3.5.1-1.mga3
+ Revision: 412346
- BR lua5.1-devel instead of lua-devel
- add missing sha1.lst
+ oden <oden>
- 3.5.1
+ mitya <mitya>
- Created package structure for pdns-recursor.

